\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{maClasse}
\LoadClass{article}

%utilisation de newcommandx
\RequirePackage{xargs}

%DEFINITION DES RACCOURCIS
\RequirePackage{mesRaccourcisEtFormules}
\newcommand{\vInst}[1]{$#1_{(t)}$}
\newcommand{\vMoy}[1]{<$#1$>}
\newcommand{\vEff}[1]{$#1_{eff}$}

%classiques
\RequirePackage[utf8]{inputenc}
% \usepackage[french]{babel}% Empèche l'insertion de figure Circuitikz !!
\RequirePackage[T1]{fontenc}

%hyperliens
\RequirePackage{hyperref}

%graphiques
\RequirePackage{graphicx,float}%float permet l'utilation de l'option[H] pour forcer l'image à être exactement à l'endroit indiqué
% \graphicspath{C:/img/}

%modification strurelle page
\parindent=0cm %permet d'enlever l'indentation sur tout le document
\parskip=0.2cm
\RequirePackage[left=2cm,right=2cm,top=2cm,bottom=3cm]{geometry}
\RequirePackage{setspace}%gestion des interlignes et interparagraphe
% https://youtu.be/X-e7HoYCR3g?list=PLxqF8KMmK3uyK1rHOy_ZE-cC9ztnkmmbl

\RequirePackage{multicol}

%en-tête et pied de page
\RequirePackage{fancyhdr} %A utiliser avec \pagestyle{}
\RequirePackage{lastpage}
\lhead{Sciences de l'ingénieur}
\chead{Cours}
\rhead{Lycée Pierre Mendès France}
\lfoot{\today}
\cfoot{}
\rfoot{Page \thepage /\pageref{LastPage} }
% \renewcommand{\headrulewidth}{0mm}%Pour faire disparaître la barre horizontale
% \renewcommand{\headrulewidth}{0.5mm}

%Modification globale de la page (pour modification locale utiliser \thispagestyle{} dans le document
\pagestyle{fancy} %utiliser plain en lieu et place de fancy pour revenir au style par défaut

%maths
\RequirePackage{mathtools}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{amsfonts}

%gestion des couleurs
\RequirePackage{color}
\RequirePackage{xcolor}


\RequirePackage{nicefrac}

%chargement de packages pour canvas de textes (bordures)
\RequirePackage{tcolorbox,bclogo,environ,wrapfig}

%pgfplots
\RequirePackage{pgfplots}
% \pgfplotsset{compat=newest}
% \pgfplotsset{compat=1.18}
\usepgfplotslibrary{statistics}
\usepgfplotslibrary{fillbetween}
\pgfplotsset{
        standard/.style={
            % axis line style = thick,
            trig format=rad,
            enlargelimits,
            axis x line=middle,
            axis y line=middle,
            enlarge x limits=0.15,
            enlarge y limits=0.15,
            every axis x label/.style={at={(current axis.right of origin)},anchor=north west},
            every axis y label/.style={at={(current axis.above origin)},anchor=south east}
        },
        compat=newest
}

%tikzpicture
\RequirePackage{tikz}
\RequirePackage{scalerel}
\RequirePackage{pict2e}
\RequirePackage{tkz-euclide}
\usetikzlibrary{calc}
\usetikzlibrary{patterns,arrows.meta}
\usetikzlibrary{shadows}
\usetikzlibrary{external}

%circuitikz
\RequirePackage[european resistor, european voltage, european current, straightvoltages, americaninductors]{circuitikz}

%GESTION DES TABLEAUX
\renewcommand{\arraystretch}{1.3}%augmente la hauteur des cellules du tableau
\RequirePackage{array}%Gestion de tableau plus simple

%INSERTION DE PAGES PDF
\RequirePackage{pdfpages}

%INSERTION PAGE PAYSAGE
\RequirePackage{lscape}
%exemple :
% \begin{landscape}
    % mon_beau_tableau
% \end{landscape}

%INSERTION CODE+++++++++++++++++++
\RequirePackage{listings}
\input{arduinoLanguage.tex}    % adds the arduino language listing
%exemple de code :

% \begin{lstlisting}[style=myArduino]
% void setup() { }
% void loop() { }
% \end{lstlisting}

%\date{November 2022}
\date{}%Empêcher la date automatique quand \maketitle